aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--config/shepherd/init.d/cmk.scm11
-rw-r--r--elisp/cmk.el2
2 files changed, 7 insertions, 6 deletions
diff --git a/elisp/cmk.el b/elisp/cmk.el
index a585e55..f70a9da 100644
--- a/elisp/cmk.el
+++ b/elisp/cmk.el
@@ -55,7 +55,7 @@ Default is \"%Y-%m-%d %H:%M\"."
(make-network-process
:name "Checkmk"
:host 'local
- :service 6565
+ :service 6557
:buffer "CMK"
:sentinel (lambda (process event)
(message "Process: %s had the event '%s'" process (string-trim event))
diff --git a/config/shepherd/init.d/cmk.scm b/config/shepherd/init.d/cmk.scm
index 20f7785..f6263ff 100644
--- a/config/shepherd/init.d/cmk.scm
+++ b/config/shepherd/init.d/cmk.scm
@@ -1,16 +1,17 @@
(register-services
(list
(service
- '(ingrid-cmk)
- #:documentation "SSH tunnel to ingrid CMK server for socket"
+ '(nina-cmk)
+ #:documentation "SSH tunnel to nina CMK server for socket"
#:start (make-forkexec-constructor
(list "ssh" "-NTv"
"-o" "ServerAliveInterval=60"
"-o" "ExitOnForwardFailure=yes"
"-o" "StreamLocalBindUnlink=yes"
- "-L" "6565:/omd/sites/ingrid/tmp/run/live"
- "ingrid@ingrid")
- #:log-file "/tmp/ingrid-cmk.log"
+ "-L" "6565:/omd/sites/nina/tmp/run/live"
+ "-L" "6557:127.0.0.1:6557"
+ "nina@nina")
+ #:log-file "/tmp/nina-cmk.log"
#:environment-variables '("SSH_AUTH_SOCK=/run/user/1000/gnupg/S.gpg-agent.ssh"))
#:stop (make-kill-destructor 2) ;; 2 is SIGINT - interupt process stream, ctrl-C
#:respawn? #t)))